==> edgeiq-0.16.1-py3-none-any.whl: edgeiq/semantic_segmentation.py <==

from edgeiq.base_service import BaseService as bs




class SemanticSegmentationResults(object):
    """
    The results of semantic segmentation from
    :class:`SemanticSegmentation`.
    """
    def __init__(self, class_map, start, end):
        pass

    @property
    def duration(self):
        pass

    @property
    def class_map(self):
        pass

    def __repr__(self):
        pass

class SemanticSegmentation(bs):
    """
    Classify every pixel in an image.

    The `build_legend()` is useful when used with the
    :class:`~edgeiq.streamer.Streamer`.

    Typical usage::

        semantic_segmentation = edgeiq.SemanticSegmentation(
                'alwaysai/enet')
        semantic_segmentation.load(engine=edgeiq.Engine.DNN)

        with edgeiq.Streamer() as streamer:
            <get image>
            results = semantic_segmentation.segment_image(image)

            text = 'Inference time: {:1.3f} s'.format(results.duration)
            text.append('Legend:')
            text.append(semantic_segmentation.build_legend())

            mask = semantic_segmentation.build_image_mask(results.class_map)
            blended = edgeiq.blend_images(image, mask, alpha=0.5)

            streamer.send_data(blended, text)

    :type model_id: string
    :param model_id: The ID of the model you want to use for
                     semantic segmentation.
    """
    def __init__(self, model_id):
        pass

    def segment_image(self, image):
        pass

    def build_image_mask(self, class_map):
        pass

    def build_legend(self):
        pass

    def build_object_map(self, class_map, class_list):
        pass

==> edgeiq-1.3.0-py3-none-any.whl: edgeiq/semantic_segmentation.py <==

from edgeiq.base_service import BaseService



class SemanticSegmentationResults(object):
    """
    The results of semantic segmentation from
    :class:`SemanticSegmentation`.
    """
    def __init__(self, class_map, start, end, image):
        pass

    @property
    def duration(self):
        pass

    @property
    def class_map(self):
        pass

    @property
    def image(self):
        pass

    def __repr__(self):
        pass

class SemanticSegmentation(BaseService):
    """
    Classify every pixel in an image.

    The `build_legend()` is useful when used with the
    :class:`~edgeiq.streamer.Streamer`.

    Typical usage::

        semantic_segmentation = edgeiq.SemanticSegmentation(
                'alwaysai/enet')
        semantic_segmentation.load(engine=edgeiq.Engine.DNN)

        with edgeiq.Streamer() as streamer:
            <get image>
            results = semantic_segmentation.segment_image(image)

            text = 'Inference time: {:1.3f} s'.format(results.duration)
            text.append('Legend:')
            text.append(semantic_segmentation.build_legend())

            mask = semantic_segmentation.build_image_mask(results.class_map)
            blended = edgeiq.blend_images(image, mask, alpha=0.5)

            streamer.send_data(blended, text)

    :type model_id: string
    :param model_id: The ID of the model you want to use for
                     semantic segmentation.
    """
    def __init__(self, model_id):
        pass

    def segment_image(self, image):
        pass

    def build_image_mask(self, class_map):
        pass

    def build_legend(self):
        pass

    def build_object_map(self, class_map, class_list):
        pass
